@@ -14,7 +14,7 @@
 #' regression".
 #'
 #' @param mapping The aesthetic mapping, usually constructed with
-#'   \code{\link[ggplot2]{aes}} or \code{\link[ggplot2]{aes_}}. Only needs to be
+#'   \code{\link[ggplot2]{aes}}. Only needs to be
 #'   set at the layer level if you are overriding the plot defaults.
 #' @param data A layer specific dataset, only needed if you want to override
 #'   the plot defaults.
@@ -326,42 +326,49 @@
 #'                 quantiles = 0.5)
 #'
 #' # Inspecting the returned data using geom_debug()
-#' \dontrun{
-#' if (requireNamespace("gginnards", quietly = TRUE)) {
+#' # This provides a quick way of finding out the names of the variables that
+#' # are available for mapping to aesthetics using after_stat().
+#'
+#' gginnards.installed <- requireNamespace("gginnards", quietly = TRUE)
+#'
+#' if (gginnards.installed)
 #'   library(gginnards)
 #'
-#' # This provides a quick way of finding out the names of the variables that
-#' # are available for mapping to aesthetics.
-#'
+#' if (gginnards.installed)
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
 #'     stat_quant_eq(formula = formula, geom = "debug")
 #'
+#' \dontrun{
+#' if (gginnards.installed)
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
 #'     stat_quant_eq(aes(label = after_stat(eq.label)),
 #'                   formula = formula, geom = "debug",
 #'                   output.type = "markdown")
 #'
+#' if (gginnards.installed)
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
 #'     stat_quant_eq(formula = formula, geom = "debug", output.type = "text")
 #'
+#' if (gginnards.installed)
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
 #'     stat_quant_eq(formula = formula, geom = "debug", output.type = "numeric")
 #'
+#' if (gginnards.installed)
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
 #'     stat_quant_eq(formula = formula, quantiles = c(0.25, 0.5, 0.75),
 #'                   geom = "debug", output.type = "text")
 #'
+#' if (gginnards.installed)
 #'   ggplot(my.data, aes(x, y)) +
 #'     geom_point() +
 #'     stat_quant_eq(formula = formula, quantiles = c(0.25, 0.5, 0.75),
 #'                   geom = "debug", output.type = "numeric")
 #' }
-#' }
 #'
 #' @export
 #'
@@ -416,29 +423,30 @@ stat_quant_eq <- function(mapping = NULL, data = NULL,
     position = position,
     show.legend = show.legend,
     inherit.aes = inherit.aes,
-    params = list(formula = formula,
-                  quantiles = quantiles,
-                  method = method,
-                  method.args = method.args,
-                  eq.with.lhs = eq.with.lhs,
-                  eq.x.rhs = eq.x.rhs,
-                  coef.digits = coef.digits,
-                  coef.keep.zeros = coef.keep.zeros,
-                  rho.digits = rho.digits,
-                  label.x = label.x,
-                  label.y = label.y,
-                  hstep = hstep,
-                  vstep = ifelse(is.null(vstep),
-                                 ifelse(grepl("label", geom),
-                                        0.10,
-                                        0.05),
-                                 vstep),
-                  npc.used = grepl("_npc", geom),
-                  output.type = output.type,
-                  na.rm = na.rm,
-                  orientation = orientation,
-                  parse = parse,
-                  ...)
+    params =
+      rlang::list2(formula = formula,
+                   quantiles = quantiles,
+                   method = method,
+                   method.args = method.args,
+                   eq.with.lhs = eq.with.lhs,
+                   eq.x.rhs = eq.x.rhs,
+                   coef.digits = coef.digits,
+                   coef.keep.zeros = coef.keep.zeros,
+                   rho.digits = rho.digits,
+                   label.x = label.x,
+                   label.y = label.y,
+                   hstep = hstep,
+                   vstep = ifelse(is.null(vstep),
+                                  ifelse(grepl("label", geom),
+                                         0.10,
+                                         0.05),
+                                  vstep),
+                   npc.used = grepl("_npc", geom),
+                   output.type = output.type,
+                   na.rm = na.rm,
+                   orientation = orientation,
+                   parse = parse,
+                   ...)
   )
 }
 
@@ -610,7 +618,9 @@ quant_eq_compute_group_fun <- function(data,
 
   # allow model formula and tau selection by method functions
   if (inherits(fm, "rq") || inherits(fm, "rqs")) {
-    formula <- fm[["formula"]]
+    # allow model formula selection by the model fit method
+    # extract formula from fitted model if possible, but fall back on argument if needed
+    formula.ls <- fail_safe_formula(fm, fun.args, verbose = TRUE)
     quantiles <- fm[["tau"]]
   } else {
     stop("Fitted model object does not inherit from class \"rq\" or \"rqs\" as expected")
@@ -632,6 +642,10 @@ quant_eq_compute_group_fun <- function(data,
     coefs.mt <- as.matrix(coefs.mt)
     colnames(coefs.mt) <- paste("tau=", fm[["tau"]], sep = "")
   }
+
+  formula <- formula.ls[[1]]
+  stopifnot(isa(formula, "formula"))
+
   formula.rhs.chr <- as.character(formula)[3]
   forced.origin <- grepl("-[[:space:]]*1|+[[:space:]]*0", formula.rhs.chr)
   if (forced.origin) {
@@ -743,7 +757,8 @@ quant_eq_compute_group_fun <- function(data,
 
   z[["fm.method"]] <- method.name
   z[["fm.class"]] <- fm.class[1]
-  z[["fm.formula,chr"]] <- format(formula)
+  z[["fm.formula"]] <- formula.ls
+  z[["fm.formula.chr"]] <- format(formula.ls)
 
   # Compute label positions
   if (is.character(label.x)) {
